import re
import unicodedata
from typing import Optional, Union, List

WORD_REGEX = '[\u200C\u0622\u0627\u0628\u067E\u062A-\u062C\u0686\u062D-\u0632\u0698\u0633-\u063A\u0641\u0642\u06A9\u06AF\u0644-\u0648\u06CCA-Za-z0-9\u06F0-\u06F9]'
NON_WORD_REGEX = '[^\u200C\u0622\u0627\u0628\u067E\u062A-\u062C\u0686\u062D-\u0632\u0698\u0633-\u063A\u0641\u0642\u06A9\u06AF\u0644-\u0648\u06CCA-Za-z0-9\u06F0-\u06F9]'


def check_standard_persian_text(text: str, includes_latin=False) -> Union[bool, str]:
    # input is normal string, like 'سلام' with no u or r
    chars = list(text)  # .decode("utf-8"))
    if includes_latin:
        valid_characters = ' ۱۲۳۴۵۶۷۸۹۰٪-+_ابپتثجچحخدذرزژسشصضطظعغفقکگلمنوهی!؟:.،؛«»"{}()[],آة|/ء<>؟*1234567890abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ;,'  # .decode("utf-8")
    else:
        valid_characters = ' ۱۲۳۴۵۶۷۸۹۰٪-+_ابپتثجچحخدذرزژسشصضطظعغفقکگلمنوهی!؟:.،؛«»"{}()[],آة|/ء<>؟*'  # .decode("utf-8")
    for ch in chars:
        if not(ch in valid_characters):
            return ch
    return True


def standardize_persian_text(text: Optional[str], may_include_latin_chars=False, remove_spaces=True, check_persian=False, replace_ascii_digits=True,
                             remove_newlines=False, remove_double_newlines=False) -> Optional[str]:
    if text is None:
        return None
    text = text.replace('ي', 'ی')
    text = text.replace('ئ', 'ی')
    text = text.replace('ك', 'ک')
    text = text.replace('ﻚ', 'ک')
    text = text.replace('ﺑ', 'ب')
    text = text.replace('ﺎ', 'ا')
    text = text.replace('ﻧ', 'ن')
    text = text.replace('ﺧ', 'خ')

    # digits
    text = replace_arabic_digits_with_farsi(text)

    if '\u200c' in text:
        text = re.sub('^\u200c', '', text, flags=re.MULTILINE)
        u200c_pattern = '\u200c' + '($|' + NON_WORD_REGEX + ')'
        p = re.compile(u200c_pattern)
        matches = [i for i in p.finditer(text)]
        for m in reversed(matches):
            text = text[:m.start()] + text[m.start() + 1:]

    text = text.replace('إ', 'ا')
    text = text.replace('ؤ', 'و')
    text = text.replace('ۀ', 'ه')
    text = text.replace('أ', 'ا')

    text = text.replace('%', '٪')

    text = text.replace('ً', '')
    text = text.replace('ٌ', '')
    text = text.replace('ٍ', '')
    text = text.replace('َ', '')
    text = text.replace('ُ', '')
    text = text.replace('', '')
    text = text.replace(u"\uFEFF", " ")  # removing zero width non breakable space character
    text = text.replace(u"\u200F", "")  # removing rtl mark character
    text = text.replace(u"\u200E", "")  # removing ltr mark character
    text = text.replace(u"\u200D", "")  # removing zero width joiner
    text = text.replace(u"\u200B", " ")  # removing zero width space
    text = text.replace(u"\u200A", " ")  # removing hair space
    # text = text.replace(u"\u200C", " ")  # removing zero width non joiner space character
    text = text.replace(u"\u00A0", " ")  # removing non break space
    text = text.replace(u"\u0640", "")  # removing arabic tatweel
    text = text.replace(u"\ufeb7", "ش")  # removing arabic letter sheen initial form
    text = text.replace(u"\ufeae", "ر")  # removing arabic letter reh final form
    text = text.replace(u"\ufe96", "ت")  # removing arabic letter teh final form
    text = text.replace(u"\ufedf", "ل")  # removing arabic letter lam initial form
    text = text.replace(u"\ufeb0", "ز")  # removing arabic letter zain final form
    text = text.replace(u"\ufee8", "ن")  # removing arabic letter noon medial form
    text = text.replace(u"\ufb93", "گ")  # removing arabic letter gaf final form
    text = text.replace(u"\ufeb3", "س")  # removing arabic letter seen initial form
    text = text.replace(u"\ufeec", "ه")  # removing arabic letter heh medial form
    text = text.replace(u"\ufee3", "م")  # removing arabic letter meem initial form
    text = text.replace(u"\ufecb", "ع")  # removing arabic letter ain initial form

    if remove_spaces:
        text = text.lstrip()
        text = text.rstrip()
        if remove_newlines:
            text = re.sub(r'\s+', ' ', text)
        else:
            text = re.sub(r'[ \f\t\r]+', ' ', text)
            text = re.sub(r'\n[ \f\t\r]+', '\n', text)
            text = re.sub(r'[ \f\t\r]+\n', '\n', text)
        if remove_double_newlines:
            text = re.sub(r'\n+', '\n', text)

    if replace_ascii_digits:
        text = replace_ascii_digits_with_farsi(text)
    if check_persian:
        check = check_standard_persian_text(text, may_include_latin_chars)
        if check is True:
            pass
        else:
            raise Exception('Invalid character: "' + check + '" unicode category: ' + str('%04x' % ord(check)) +
                            ' which unicode name of  "' + unicodedata.name(check) + '" in text ' + text)
    return text


def remove_extra_spaces(text: str) -> str:
    text = text.lstrip()
    text = text.rstrip()
    text = re.sub(r'\s+', ' ', text)
    return text


def remove_double_spaces(text: str) -> str:
    text = re.sub(r'\s+', ' ', text)
    return text


def replace_farsi_digits_with_ascii(text: str) -> str:
    text = text.replace('\u06f0', '0')
    text = text.replace('\u06f1', '1')
    text = text.replace('\u06f2', '2')
    text = text.replace('\u06f3', '3')
    text = text.replace('\u06f4', '4')
    text = text.replace('\u06f5', '5')
    text = text.replace('\u06f6', '6')
    text = text.replace('\u06f7', '7')
    text = text.replace('\u06f8', '8')
    text = text.replace('\u06f9', '9')
    return text


def replace_arabic_digits_with_ascii(text: str) -> str:
    text = text.replace('\u0660', '0')
    text = text.replace('\u0661', '1')
    text = text.replace('\u0662', '2')
    text = text.replace('\u0663', '3')
    text = text.replace('\u0664', '4')
    text = text.replace('\u0665', '5')
    text = text.replace('\u0666', '6')
    text = text.replace('\u0667', '7')
    text = text.replace('\u0668', '8')
    text = text.replace('\u0669', '9')
    return text


def replace_ascii_digits_with_farsi(text: str) -> str:
    text = text.replace('0', '۰')
    text = text.replace('1', '۱')
    text = text.replace('2', '۲')
    text = text.replace('3', '۳')
    text = text.replace('4', '۴')
    text = text.replace('5', '۵')
    text = text.replace('6', '۶')
    text = text.replace('7', '۷')
    text = text.replace('8', '۸')
    text = text.replace('9', '۹')
    return text


def replace_arabic_digits_with_farsi(text: str) -> str:
    text = text.replace('\u0660', '\u06f0')
    text = text.replace('\u0661', '\u06f1')
    text = text.replace('\u0662', '\u06f2')
    text = text.replace('\u0663', '\u06f3')
    text = text.replace('\u0664', '\u06f4')
    text = text.replace('\u0665', '\u06f5')
    text = text.replace('\u0666', '\u06f6')
    text = text.replace('\u0667', '\u06f7')
    text = text.replace('\u0668', '\u06f8')
    text = text.replace('\u0669', '\u06f9')
    return text


def stop_words() -> List[str]:
    return [
        '!',
        '"',
        '#',
        ',',
        '-',
        '/',
        ':',
        '«',
        '»',
        '،',
        '؛',
        '؟',
        '۰',
        '۱',
        '۲',
        '۳',
        '۴',
        '۵',
        '۶',
        '۷',
        '۸',
        '۹',
        '…',
        '$',
        '!',
        ',',
        ':',
        ';',
        '،',
        '؛',
        '؟',
        'آباد',
        'آره',
        'آری',
        'آمد',
        'آمده',
        'آن',
        'آنان',
        'آنجا',
        'آنطور',
        'آنقدر',
        'آنکه',
        'آنها',
        'آنچه',
        'آنکه',
        'آورد',
        'آورده',
        'آید',
        'آی',
        'آیا',
        'آیند',
        'اتفاقا',
        'اثر',
        'احتراما',
        'احتمالا',
        'اخیر',
        'اری',
        'از',
        'ازجمله',
        'اساسا',
        'است',
        'استفاد',
        'استفاده',
        'اش',
        'اشکارا',
        'اصلا',
        'اصولا',
        'اعلام',
        'اغلب',
        'اکنون',
        'الان',
        'البته',
        'البتّه',
        'ام',
        'اما',
        'امروز',
        'امروزه',
        'امسال',
        'امشب',
        'امور',
        'ان',
        'انجام',
        'اند',
        'انشاالله',
        'انصافا',
        'انطور',
        'انقدر',
        'انها',
        'انچنان',
        'انکه',
        'انگار',
        'او',
        'اول',
        'اولا',
        'ای',
        'ایشان',
        'ایم',
        'این',
        'اینکه',
        'اکثرا',
        'اکنون',
        'اگر',
        'ای',
        'ایا',
        'اید',
        'ایشان',
        'ایم',
        'این',
        'اینجا',
        'ایند',
        'اینطور',
        'اینقدر',
        'اینها',
        'اینچنین',
        'اینک',
        'اینکه',
        'اینگونه',
        'با',
        'بار',
        'بارة',
        'باره',
        'بارها',
        'باز',
        'بازهم',
        'باش',
        'باشد',
        'باشم',
        'باشند',
        'باشیم',
        'باشی',
        'باشید',
        'باشیم',
        'بالا',
        'بالاخره',
        'بالای',
        'بالطبع',
        'باید',
        'باید',
        'بتوان',
        'بتواند',
        'بتوانی',
        'بتوانیم',
        'بخش',
        'بخشی',
        'بخواه',
        'بخواهد',
        'بخواهم',
        'بخواهند',
        'بخواهی',
        'بخواهید',
        'بخواهیم',
        'بد',
        'بدون',
        'بر',
        'برابر',
        'برابر',
        'براحتی',
        'براساس',
        'براستی',
        'برای',
        'برای',
        'برای',
        'برخوردار',
        'برخی',
        'برخی',
        'برداری',
        'برعکس',
        'بروز',
        'بزرگ',
        'بزودی',
        'بسا',
        'بسیار',
        'بسیاری',
        'بسیار',
        'بسیاری',
        'بطور',
        'بعد',
        'بعدا',
        'بعدها',
        'بعری',
        'بعضا',
        'بعضی',
        'بلافاصله',
        'بلکه',
        'بله',
        'بلکه',
        'بلی',
        'بنابراین',
        'بنابراین',
        'بندی',
        'به',
        'بهتر',
        'بهترین',
        'بود',
        'بودم',
        'بودن',
        'بودند',
        'بوده',
        'بودی',
        'بودید',
        'بودیم',
        'بویژه',
        'بی',
        'بیست',
        'بیش',
        'بیشتر',
        'بیشتری',
        'بین',
        'بکن',
        'بکند',
        'بکنم',
        'بکنند',
        'بکنی',
        'بکنید',
        'بکنیم',
        'بگو',
        'بگوید',
        'بگویم',
        'بگویند',
        'بگویی',
        'بگویید',
        'بگوییم',
        'بگیر',
        'بگیرد',
        'بگیرم',
        'بگیرند',
        'بگیری',
        'بگیرید',
        'بگیریم',
        'بی',
        'بیا',
        'بیاب',
        'بیابد',
        'بیابم',
        'بیابند',
        'بیابی',
        'بیابید',
        'بیابیم',
        'بیاور',
        'بیاورد',
        'بیاورم',
        'بیاورند',
        'بیاوری',
        'بیاورید',
        'بیاوریم',
        'بیاید',
        'بیایم',
        'بیایند',
        'بیایی',
        'بیایید',
        'بیاییم',
        'بیرون',
        'بیرون',
        'بیش',
        'بیشتر',
        'بیشتری',
        'بین',
        'ت',
        'تا',
        'تازه',
        'تاکنون',
        'تان',
        'تاکنون',
        'تحت',
        'تر',
        'تر  براساس',
        'ترین',
        'تقریبا',
        'تلویحا',
        'تمام',
        'تماما',
        'تمامی',
        'تنها',
        'تو',
        'تواند',
        'توانست',
        'توانستم',
        'توانستن',
        'توانستند',
        'توانسته',
        'توانستی',
        'توانستیم',
        'توانم',
        'توانند',
        'توانی',
        'توانید',
        'توانیم',
        'توسط',
        'تول',
        'توی',
        'ثانیا',
        'جا',
        'جای',
        'جایی',
        'جای',
        'جدا',
        'جدید',
        'جدید',
        'جریان',
        'جریان',
        'جز',
        'جلوگیری',
        'جلوی',
        'جمعا',
        'جناح',
        'جهت',
        'حاضر',
        'حال',
        'حالا',
        'حتما',
        'حتی',
        'حتی',
        'حداکثر',
        'حدودا',
        'حدود',
        'حق',
        'خارج',
        'خدمات',
        'خصوصا',
        'خلاصه',
        'خواست',
        'خواستم',
        'خواستن',
        'خواستند',
        'خواسته',
        'خواستی',
        'خواستید',
        'خواستیم',
        'خواهد',
        'خواهم',
        'خواهند',
        'خواهیم',
        'خواهی',
        'خواهید',
        'خواهیم',
        'خوب',
        'خود',
        'خودت',
        'خودتان',
        'خودش',
        'خودشان',
        'خودم',
        'خودمان',
        'خوشبختانه',
        'خویش',
        'خویش',
        'خویشتن',
        'خیاه',
        'خیر',
        'خیلی',
        'داد',
        'دادم',
        'دادن',
        'دادند',
        'داده',
        'دادی',
        'دادید',
        'دادیم',
        'دار',
        'دارد',
        'دارم',
        'دارند',
        'داریم',
        'داری',
        'دارید',
        'داریم',
        'داشت',
        'داشتم',
        'داشتن',
        'داشتند',
        'داشته',
        'داشتی',
        'داشتید',
        'داشتیم',
        'دانست',
        'دانند',
        'دایم',
        'دایما',
        'در',
        'درباره',
        'درمجموع',
        'درون',
        'دریغ',
        'دقیقا',
        'دنبال',
        'ده',
        'دهد',
        'دهم',
        'دهند',
        'دهی',
        'دهید',
        'دهیم',
        'دو',
        'دوباره',
        'دوم',
        'دیده',
        'دیروز',
        'دیگر',
        'دیگران',
        'دیگری',
        'دیر',
        'دیروز',
        'دیگر',
        'دیگران',
        'دیگری',
        'را',
        'راحت',
        'راسا',
        'راستی',
        'راه',
        'رسما',
        'رسید',
        'رفت',
        'رفته',
        'رو',
        'روب',
        'روز',
        'روزانه',
        'روزهای',
        'روی',
        'روی',
        'روی',
        'ریزی',
        'زمان',
        'زمانی',
        'زمینه',
        'زود',
        'زیاد',
        'زیر',
        'زیرا',
        'زیر',
        'زیر',
        'سابق',
        'ساخته',
        'سازی',
        'سالانه',
        'سالیانه',
        'سایر',
        'سراسر',
        'سرانجام',
        'سریعا',
        'سری',
        'سعی',
        'سمت',
        'سوم',
        'سوی',
        'سوی',
        'سپس',
        'شان',
        'شاید',
        'شاید',
        'شخصا',
        'شد',
        'شدم',
        'شدن',
        'شدند',
        'شده',
        'شدی',
        'شدید',
        'شدیدا',
        'شدیم',
        'شش',
        'شش  نداشته',
        'شما',
        'شناسی',
        'شود',
        'شوم',
        'شوند',
        'شونده',
        'شوی',
        'شوید',
        'شویم',
        'صرفا',
        'صورت',
        'ضد',
        'ضمن',
        'طبعا',
        'طبق',
        'طبیعتا',
        'طرف',
        'طریق',
        'طریق',
        'طور',
        'طی',
        'طی',
        'ظاهرا',
        'عدم',
        'عقب',
        'علّت',
        'علیه',
        'عمدا',
        'عمدتا',
        'عمل',
        'عملا',
        'عنوان',
        'عنوان',
        'غالبا',
        'غیر',
        'غیر',
        'فردا',
        'فعلا',
        'فقط',
        'فکر',
        'فوق',
        'قابل',
        'قبل',
        'قبلا',
        'قدری',
        'قصد',
        'قطعا',
        'کرد',
        'کردم',
        'کردن',
        'کردند',
        'کرده',
        'کسی',
        'کل',
        'کمتر',
        'کند',
        'کنم',
        'کنند',
        'کنید',
        'کنیم',
        'که',
        'اینم',
        'شما',
        'لااقل',
        'لطفا',
        'لطفاً',
        'ما',
        'مان',
        'مانند',
        'مانند',
        'مبادا',
        'متاسفانه',
        'متعاقبا',
        'مثل',
        'مثلا',
        'مثل',
        'مجانی',
        'مجددا',
        'مجموعا',
        'مختلف',
        'مدام',
        'مدت',
        'مدّتی',
        'مردم',
        'مرسی',
        'مستقیما',
        'مسلما',
        'مطمینا',
        'معمولا',
        'مقابل',
        'ممکن',
        'من',
        'موارد',
        'مورد',
        'موقتا',
        'می',
        'میلیارد',
        'میلیون',
        'مگر',
        'می',
        'می شود',
        'میان',
        'می‌رسد',
        'می‌رود',
        'می‌شود',
        'می‌کنیم',
        'ناشی',
        'نام',
        'ناگاه',
        'ناگهان',
        'ناگهانی',
        'نباید',
        'نباید',
        'نبود',
        'نخست',
        'نخستین',
        'نخواهد',
        'نخواهم',
        'نخواهند',
        'نخواهی',
        'نخواهید',
        'نخواهیم',
        'ندارد',
        'ندارم',
        'ندارند',
        'نداری',
        'ندارید',
        'نداریم',
        'نداشت',
        'نداشتم',
        'نداشتند',
        'نداشته',
        'نداشتی',
        'نداشتید',
        'نداشتیم',
        'نزدیک',
        'نزد',
        'نزدیک',
        'نسبتا',
        'نشان',
        'نشده',
        'نظیر',
        'نظیر',
        'نکرده',
        'نماید',
        'نمی',
        'نمی',
        'نمی‌شود',
        'نه',
        'نهایتا',
        'نوع',
        'نوعی',
        'نوعی',
        'نیز',
        'نیست',
        'نگاه',
        'نیز',
        'نیست',
        'ها',
        'های',
        'هایی',
        'های',
        'هایی',
        'هبچ',
        'هر',
        'هرچه',
        'هرگز',
        'هزار',
        'هست',
        'هستم',
        'هستند',
        'هستیم',
        'هستی',
        'هستید',
        'هستیم',
        'هفت',
        'هم',
        'همان',
        'همه',
        'همواره',
        'همین',
        'همچنان',
        'همچنین',
        'همچنین',
        'همچون',
        'همیشه',
        'میشه',
        'داره',
        'میکنن',
        'واسه',
        'اینه',
        'منم',
        'منو',
        'برم',
        'کنن',
        'کنم',
        'میگه',
        'اینا',
        'الان',
        'الآن',
        'میخوام',
        'نیس',
        'هس',
        'ینی',
        'دونم',
        'رفتم',
        'شه',
        'شم',
        'خوام',
        'میاد',
        'بشه',
        'انقد',
        'چقد',
        'اصن',
        'اصلا',
        'حالا',
        'میکنه',
        'کنه',
        'بده',
        'باشه',
        'ببین',
        'همین',
        'هنوز',
        'هنگام',
        'هنگام',
        'هنگامی',
        'هیچ',
        'هیچ',
        'هیچگاه',
        'و',
        'واقعا',
        'واقعی',
        'وجود',
        'وسط',
        'وضع',
        'وقتی',
        'وقتی',
        'وقتیکه',
        'ولی',
        'وی',
        'وگو',
        'وی',
        'ویژه',
        'یا',
        'یابد',
        'یک',
        'یکدیگر',
        'یکی',
        'ّه',
        '٪',
        'پارسال',
        'پاعین',
        'پس',
        'پنج',
        'پیش',
        'پیدا',
        'پیش',
        'پیشاپیش',
        'پیشتر',
        'پیش',
        'چرا',
        'چطور',
        'چقدر',
        'همینقدر',
        'ندین',
        'نوشتم',
        'افتادم',
        'چنان',
        'چنانچه',
        'چنانکه',
        'چند',
        'چندین',
        'چنین',
        'چنین',
        'چه',
        'چهار',
        'چو',
        'چون',
        'چیزی',
        'چگونه',
        'چیز',
        'چیزی',
        'چیست',
        'کاش',
        'کامل',
        'کاملا',
        'کتبا',
        'کجا',
        'کجاست',
        'کدام',
        'کرد',
        'کردم',
        'کردن',
        'کردند',
        'کرده',
        'کردی',
        'کردید',
        'کردیم',
        'کس',
        'کسانی',
        'کسی',
        'کل',
        'کلا',
        'کم',
        'کماکان',
        'کمتر',
        'کمتری',
        'کمی',
        'کن',
        'کنار',
        'کنار',
        'کند',
        'کنم',
        'کنند',
        'کننده',
        'کنون',
        'کنونی',
        'کنی',
        'کنید',
        'کنیم',
        'که',
        'کو',
        'کَی',
        'کی',
        'گاه',
        'گاهی',
        'گذاری',
        'گذاشته',
        'گذشته',
        'گردد',
        'گرفت',
        'گرفتم',
        'گرفتن',
        'گرفتند',
        'گرفته',
        'گرفتی',
        'گرفتید',
        'گرفتیم',
        'گروهی',
        'گفت',
        'گفتم',
        'گفتن',
        'گفتند',
        'گفته',
        'گفتی',
        'گفتید',
        'گفتیم',
        'گه',
        'گهگاه',
        'گو',
        'گوید',
        'گویند',
        'گویا',
        'گوید',
        'گویم',
        'گویند',
        'گویی',
        'گویید',
        'گوییم',
        'گیرد',
        'گیری',
        'گیرد',
        'گیرم',
        'گیرند',
        'گیری',
        'گیرید',
        'گیریم',
        'ی',
        'یا',
        'یابد',
        'یابم',
        'یابند',
        'یابی',
        'یابید',
        'یابیم',
        'یافت',
        'یافتم',
        'یافتن',
        'یافته',
        'یافتی',
        'یافتید',
        'یافتیم',
        'یعنی',
        'یقینا',
        'یه',
        'یک',
        'یکی',
        '۰',
        '۱',
        '۲',
        '۳',
        '۴',
        '۵',
        '۶',
        '۷',
        '۸',
        '۹',
        'دیگران',
        'همچنان',
        'مدت',
        'چیز',
        'سایر',
        'جا',
        'طی',
        'کل',
        'کنونی',
        'بیرون',
        'مثلا',
        'کامل',
        'کاملا',
        'آنکه',
        'موارد',
        'واقعی',
        'امور',
        'اکنون',
        'بطور',
        'بخشی',
        'تحت',
        'چگونه',
        'عدم',
        'نوعی',
        'حاضر',
        'وضع',
        'مقابل',
        'کنار',
        'خویش',
        'نگاه',
        'درون',
        'زمانی',
        'بنابراین',
        'تو',
        'خیلی',
        'بزرگ',
        'خودش',
        'جز',
        'اینجا',
        'مختلف',
        'توسط',
        'نوع',
        'همچنین',
        'آنجا',
        'قبل',
        'جناح',
        'اینها',
        'طور',
        'شاید',
        'ایشان',
        'جهت',
        'طریق',
        'مانند',
        'پیدا',
        'ممکن',
        'کسانی',
        'جای',
        'کسی',
        'غیر',
        'بی',
        'قابل',
        'درباره',
        'جدید',
        'وقتی',
        'اخیر',
        'چرا',
        'بیش',
        'روی',
        'طرف',
        'جریان',
        'زیر',
        'آنچه',
        'البته',
        'فقط',
        'چیزی',
        'چون',
        'برابر',
        'هنوز',
        'بخش',
        'زمینه',
        'بین',
        'بدون',
        'استفاد',
        'همان',
        'نشان',
        'بسیاری',
        'بعد',
        'عمل',
        'روز',
        'اعلام',
        'چند',
        'آنان',
        'بلکه',
        'امروز',
        'تمام',
        'بیشتر',
        'آیا',
        'برخی',
        'علیه',
        'دیگری',
        'ویژه',
        'گذشته',
        'انجام',
        'حتی',
        'داده',
        'راه',
        'سوی',
        'ولی',
        'زمان',
        'حال',
        'تنها',
        'بسیار',
        'یعنی',
        'عنوان',
        'همین',
        'هبچ',
        'پیش',
        'وی',
        'یکی',
        'اینکه',
        'وجود',
        'شما',
        'پس',
        'چنین',
        'میان',
        'مورد',
        'چه',
        'اگر',
        'همه',
        'نه',
        'دیگر',
        'آنها',
        'باید',
        'هر',
        'او',
        'ما',
        'من',
        'تا',
        'نیز',
        'اما',
        'یک',
        'خود',
        'بر',
        'یا',
        'هم',
        'را',
        'این',
        'با',
        'آن',
        'برای',
        'و',
        'در',
        'به',
        'که',
        'از',
        'و',
        'در',
        'به',
        'از',
        'که',
        'می',
        'این',
        'است',
        'را',
        'با',
        'های',
        'برای',
        'آن',
        'یک',
        'شود',
        'شده',
        'خود',
        'ها',
        'کرد',
        'شد',
        'ای',
        'تا',
        'کند',
        'بر',
        'بود',
        'گفت',
        'نیز',
        'وی',
        'هم',
        'کنند',
        'دارد',
        'ما',
        'کرده',
        'یا',
        'اما',
        'باید',
        'دو',
        'اند',
        'هر',
        'خواهد',
        'او',
        'مورد',
        'آنها',
        'باشد',
        'دیگر',
        'مردم',
        'نمی',
        'بین',
        'پیش',
        'پس',
        'اگر',
        'همه',
        'صورت',
        'یکی',
        'هستند',
        'بی',
        'من',
        'دهد',
        'هزار',
        'نیست',
        'استفاده',
        'داد',
        'داشته',
        'راه',
        'داشت',
        'چه',
        'همچنین',
        'کردند',
        'داده',
        'بوده',
        'دارند',
        'همین',
        'میلیون',
        'سوی',
        'شوند',
        'بیشتر',
        'بسیار',
        'روی',
        'گرفته',
        'هایی',
        'تواند',
        'اول',
        'نام',
        'هیچ',
        'چند',
        'جدید',
        'بیش',
        'شدن',
        'کردن',
        'کنیم',
        'نشان',
        'حتی',
        'اینکه',
        'ولی',
        'توسط',
        'چنین',
        'برخی',
        'نه',
        'دیروز',
        'دوم',
        'درباره',
        'بعد',
        'مختلف',
        'گیرد',
        'شما',
        'گفته',
        'آنان',
        'بار',
        'طور',
        'گرفت',
        'دهند',
        'گذاری',
        'بسیاری',
        'طی',
        'بودند',
        'میلیارد',
        'بدون',
        'تمام',
        'کل',
        'تر  براساس',
        'شدند',
        'ترین',
        'امروز',
        'باشند',
        'ندارد',
        'چون',
        'قابل',
        'گوید',
        'دیگری',
        'همان',
        'خواهند',
        'قبل',
        'آمده',
        'اکنون',
        'تحت',
        'طریق',
        'گیری',
        'جای',
        'هنوز',
        'چرا',
        'البته',
        'کنید',
        'سازی',
        'سوم',
        'کنم',
        'بلکه',
        'زیر',
        'توانند',
        'ضمن',
        'فقط',
        'بودن',
        'حق',
        'آید',
        'وقتی',
        'اش',
        'یابد',
        'نخستین',
        'مقابل',
        'خدمات',
        'امسال',
        'تاکنون',
        'مانند',
        'تازه',
        'آورد',
        'فکر',
        'آنچه',
        'نخست',
        'نشده',
        'شاید',
        'چهار',
        'جریان',
        'پنج',
        'ساخته',
        'زیرا',
        'نزدیک',
        'برداری',
        'کسی',
        'ریزی',
        'رفت',
        'گردد',
        'مثل',
        'آمد',
        'ام',
        'بهترین',
        'دانست',
        'کمتر',
        'دادن',
        'تمامی',
        'جلوگیری',
        'بیشتری',
        'ایم',
        'ناشی',
        'چیزی',
        'آنکه',
        'بالا',
        'بنابراین',
        'ایشان',
        'بعضی',
        'دادند',
        'داشتند',
        'برخوردار',
        'نخواهد',
        'هنگام',
        'نباید',
        'غیر',
        'نبود',
        'دیده',
        'وگو',
        'داریم',
        'چگونه',
        'بندی',
        'خواست',
        'فوق',
        'ده',
        'نوعی',
        'هستیم',
        'دیگران',
        'همچنان',
        'سراسر',
        'ندارند',
        'گروهی',
        'سعی',
        'روزهای',
        'آنجا',
        'یکدیگر',
        'کردم',
        'بیست',
        'بروز',
        'سپس',
        'رفته',
        'آورده',
        'نماید',
        'باشیم',
        'گویند',
        'زیاد',
        'خویش',
        'همواره',
        'گذاشته',
        'شش  نداشته',
        'شناسی',
        'خواهیم',
        'آباد',
        'داشتن',
        'نظیر',
        'همچون',
        'باره',
        'نکرده',
        'شان',
        'سابق',
        'هفت',
        'دانند',
        'جایی',
        'بی',
        'جز',
        'زیر',
        'روی',
        'سری',
        'توی',
        'جلوی',
        'پیش',
        'عقب',
        'بالای',
        'خارج',
        'وسط',
        'بیرون',
        'سوی',
        'کنار',
        'پاعین',
        'نزد',
        'نزدیک',
        'دنبال',
        'حدود',
        'برابر',
        'طبق',
        'مانند',
        'ضدّ',
        'هنگام',
        'برای',
        'مثل',
        'بارة',
        'اثر',
        'تول',
        'علّت',
        'سمت',
        'عنوان',
        'قصد',
        'روب',
        'جدا',
        'کی',
        'که',
        'چیست',
        'هست',
        'کجا',
        'کجاست',
        'کَی',
        'چطور',
        'کدام',
        'آیا',
        'مگر',
        'چندین',
        'یک',
        'چیزی',
        'دیگر',
        'کسی',
        'بعری',
        'هیچ',
        'چیز',
        'جا',
        'کس',
        'هرگز',
        'یا',
        'تنها',
        'بلکه',
        'خیاه',
        'بله',
        'بلی',
        'آره',
        'آری',
        'مرسی',
        'البتّه',
        'لطفاً',
        'ّه',
        'انکه',
        'وقتیکه',
        'همین',
        'پیش',
        'مدّتی',
        'هنگامی',
        'مان',
        'تان',
        '!',
        '"',
        '#',
        ',',
        '-',
        '/',
        ':',
        '«',
        '»',
        '،',
        '؛',
        '؟',
        'آباد',
        'آخ',
        'آخر',
        'آخرها',
        'آخه',
        'آدمهاست',
        'آرام',
        'آرام آرام',
        'آره',
        'آری',
        'آزادانه',
        'آسان',
        'آسیب پذیرند',
        'آشنایند',
        'آشکارا',
        'آقا',
        'آقای',
        'آقایان',
        'آمد',
        'آمدن',
        'آمده',
        'آمرانه',
        'آن',
        'آن گاه',
        'آنان',
        'آنانی',
        'آنجا',
        'آنرا',
        'آنطور',
        'آنقدر',
        'آنها',
        'آنهاست',
        'آنچنان',
        'آنچنان که',
        'آنچه',
        'آنکه',
        'آنگاه',
        'آن‌ها',
        'آهان',
        'آهای',
        'آور',
        'آورد',
        'آوردن',
        'آورده',
        'آوه',
        'آی',
        'آیا',
        'آید',
        'آیند',
        'ا',
        'اتفاقا',
        'اثر',
        'اجراست',
        'احتراما',
        'احتمالا',
        'احیاناً',
        'اخیر',
        'اخیراً',
        'اری',
        'از',
        'از آن پس',
        'از جمله',
        'ازاین رو',
        'ازجمله',
        'ازش',
        'اساسا',
        'اساساً',
        'است',
        'استفاد',
        'استفاده',
        'اسلامی اند',
        'اش',
        'اشتباها',
        'اشکارا',
        'اصلا',
        'اصلاً',
        'اصولا',
        'اصولاً',
        'اعلام',
        'اغلب',
        'افزود',
        'افسوس',
        'اقل',
        'اقلیت',
        'الا',
        'الان',
        'البته',
        'البتّه',
        'الهی',
        'الی',
        'ام',
        'اما',
        'امروز',
        'امروزه',
        'امسال',
        'امشب',
        'امور',
        'امیدوارم',
        'امیدوارند',
        'امیدواریم',
        'ان',
        'ان شاأالله',
        'انتها',
        'انجام',
        'اند',
        'اندکی',
        'انشاالله',
        'انصافا',
        'انطور',
        'انقدر',
        'انها',
        'انچنان',
        'انکه',
        'انگار',
        'او',
        'اوست',
        'اول',
        'اولا',
        'اولاً',
        'اولین',
        'اون',
        'اکثر',
        'اکثرا',
        'اکثراً',
        'اکثریت',
        'اکنون',
        'اگر',
        'اگر چه',
        'اگرچه',
        'اگه',
        'ای',
        'ایا',
        'اید',
        'ایشان',
        'ایم',
        'این',
        'این جوری',
        'این قدر',
        'این گونه',
        'اینان',
        'اینجا',
        'اینجاست',
        'ایند',
        'اینطور',
        'اینقدر',
        'اینها',
        'اینهاست',
        'اینو',
        'اینچنین',
        'اینک',
        'اینکه',
        'اینگونه',
        'ب ',
        'با',
        'بااین حال',
        'بااین وجود',
        'باد',
        'بار',
        'بارة',
        'باره',
        'بارها',
        'باز',
        'باز هم',
        'بازهم',
        'بازی کنان',
        'بازیگوشانه',
        'باش',
        'باشد',
        'باشم',
        'باشند',
        'باشی',
        'باشید',
        'باشیم',
        'بالا',
        'بالاخره',
        'بالاخص',
        'بالاست',
        'بالای',
        'بالای',
        'بالطبع',
        'بالعکس',
        'باوجودی که',
        'باورند',
        'باید',
        'بتدریج',
        'بتوان',
        'بتواند',
        'بتوانی',
        'بتوانیم',
        'بجز',
        'بخش',
        'بخشه',
        'بخشی',
        'بخصوص',
        'بخواه',
        'بخواهد',
        'بخواهم',
        'بخواهند',
        'بخواهی',
        'بخواهید',
        'بخواهیم',
        'بخوبی',
        'بد',
        'بدان',
        'بدانجا',
        'بدانها',
        'بدهید',
        'بدون',
        'بدین',
        'بدین ترتیب',
        'بدینجا',
        'بر',
        'برآنند',
        'برا',
        'برابر',
        'برابر',
        'براحتی',
        'براساس',
        'براستی',
        'برای',
        'برایت',
        'برایش',
        'برایشان',
        'برایم',
        'برایمان',
        'برای',
        'برخوردار',
        'برخوردارند',
        'برخی',
        'برداری',
        'برعکس',
        'برنامه سازهاست',
        'بروز',
        'بروشنی',
        'بزرگ',
        'بزودی',
        'بس',
        'بسا',
        'بسادگی',
        'بسختی',
        'بسوی',
        'بسی',
        'بسیار',
        'بسیاری',
        'بشدت',
        'بطور',
        'بطوری که',
        'بعد',
        'بعد از این که',
        'بعدا',
        'بعدازظهر',
        'بعداً',
        'بعدها',
        'بعری',
        'بعضا',
        'بعضی',
        'بعضی شان',
        'بعضیهایشان',
        'بعضی‌ها',
        'بعلاوه',
        'بعید',
        'بفهمی نفهمی',
        'بلافاصله',
        'بله',
        'بلکه',
        'بلی',
        'بماند',
        'بنابراین',
        'بندی',
        'به',
        'به آسانی',
        'به تازگی',
        'به تدریج',
        'به تمامی',
        'به جای',
        'به جز',
        'به خوبی',
        'به درشتی',
        'به دلخواه',
        'به راستی',
        'به رغم',
        'به روشنی',
        'به زودی',
        'به سادگی',
        'به سرعت',
        'به شان',
        'به شدت',
        'به طور کلی',
        'به طوری که',
        'به علاوه',
        'به قدری',
        'به مراتب',
        'به ناچار',
        'به هرحال',
        'به هیچ وجه',
        'به وضوح',
        'به ویژه',
        'به کرات',
        'به گرمی',
        'بهت',
        'بهتر',
        'بهترین',
        'بهش',
        'بود',
        'بودم',
        'بودن',
        'بودند',
        'بوده',
        'بودی',
        'بودید',
        'بودیم',
        'بویژه',
        'بپا',
        'بکار',
        'بکن',
        'بکند',
        'بکنم',
        'بکنند',
        'بکنی',
        'بکنید',
        'بکنیم',
        'بگذاریم',
        'بگو',
        'بگوید',
        'بگویم',
        'بگویند',
        'بگویی',
        'بگویید',
        'بگوییم',
        'بگیر',
        'بگیرد',
        'بگیرم',
        'بگیرند',
        'بگیری',
        'بگیرید',
        'بگیریم',
        'بی',
        'بی آنکه',
        'بی اطلاعند',
        'بی تردید',
        'بی تفاوتند',
        'بی نیازمندانه',
        'بی هدف',
        'بیا',
        'بیاب',
        'بیابد',
        'بیابم',
        'بیابند',
        'بیابی',
        'بیابید',
        'بیابیم',
        'بیاور',
        'بیاورد',
        'بیاورم',
        'بیاورند',
        'بیاوری',
        'بیاورید',
        'بیاوریم',
        'بیاید',
        'بیایم',
        'بیایند',
        'بیایی',
        'بیایید',
        'بیاییم',
        'بیرون',
        'بیرون',
        'بیست',
        'بیش',
        'بیشتر',
        'بیشتری',
        'بین',
        'بیگمان',
        'ت',
        'تا',
        'تازه',
        'تان',
        'تاکنون',
        'تحت',
        'تحریم هاست',
        'تر',
        'تر براساس',
        'تریلیارد',
        'تریلیون',
        'ترین',
        'تصریحاً',
        'تعدادی',
        'تعمدا',
        'تقریبا',
        'تقریباً',
        'تلویحا',
        'تلویحاً',
        'تمام',
        'تمام قد',
        'تماما',
        'تمامشان',
        'تمامی',
        'تند تند',
        'تنها',
        'تو',
        'توؤماً',
        'توان',
        'تواند',
        'توانست',
        'توانستم',
        'توانستن',
        'توانستند',
        'توانسته',
        'توانستی',
        'توانستیم',
        'توانم',
        'توانند',
        'توانی',
        'توانید',
        'توانیم',
        'توسط',
        'تول',
        'توی',
        'توی',
        'تک تک',
        'ث',
        'ثالثاً',
        'ثانیا',
        'ثانیاً',
        'ج',
        'جا',
        'جای',
        'جایی',
        'جدا',
        'جداً',
        'جداگانه',
        'جدید',
        'جدیدا',
        'جرمزاست',
        'جریان',
        'جز',
        'جلو',
        'جلوگیری',
        'جلوی',
        'جلوی',
        'جمع اند',
        'جمعا',
        'جمعی',
        'جنابعالی',
        'جناح',
        'جنس اند',
        'جهت',
        'جور',
        'ح',
        'حاشیه‌ای',
        'حاضر',
        'حاضرم',
        'حال',
        'حالا',
        'حاکیست',
        'حتما',
        'حتماً',
        'حتی',
        'حداقل',
        'حداکثر',
        'حدود',
        'حدودا',
        'حدود',
        'حسابگرانه',
        'حضرتعالی',
        'حق',
        'حقیرانه',
        'حقیقتا',
        'حول',
        'حکماً',
        'خ',
        'خارج',
        'خالصانه',
        'خب',
        'خداحافظ',
        'خداست',
        'خدمات',
        'خسته‌ای',
        'خصوصا',
        'خصوصاً',
        'خلاصه',
        'خواست',
        'خواستم',
        'خواستن',
        'خواستند',
        'خواسته',
        'خواستی',
        'خواستید',
        'خواستیم',
        'خواه',
        'خواهد',
        'خواهم',
        'خواهند',
        'خواهی',
        'خواهید',
        'خواهیم',
        'خوب',
        'خوبه',
        'خب',
        'خود',
        'خود به خود',
        'خودبه خودی',
        'خودت',
        'خودتان',
        'خودتو',
        'خودش',
        'خودشان',
        'خودم',
        'خودمان',
        'خودمو',
        'خوش',
        'خوشبختانه',
        'خویش',
        'خویشتن',
        'خویشتنم',
        'خیاه',
        'خیر',
        'خیره',
        'خیلی',
        'د',
        'دا',
        'داام',
        'دااما',
        'داخل',
        'داد',
        'دادم',
        'دادن',
        'دادند',
        'داده',
        'دادی',
        'دادید',
        'دادیم',
        'دار',
        'داراست',
        'دارد',
        'دارم',
        'دارند',
        'داری',
        'دارید',
        'داریم',
        'داشت',
        'داشتم',
        'داشتن',
        'داشتند',
        'داشته',
        'داشتی',
        'داشتید',
        'داشتیم',
        'دامم',
        'دانست',
        'دانند',
        'دایم',
        'دایما',
        'در',
        'در باره',
        'در بارهٌ',
        'در ثانی',
        'در مجموع',
        'در نهایت',
        'در واقع',
        'در کل',
        'در کنار',
        'دراین میان',
        'درباره',
        'درحالی که',
        'درحالیکه',
        'درست',
        'درست و حسابی',
        'درسته',
        'درصورتی که',
        'درعین حال',
        'درمجموع',
        'درواقع',
        'درون',
        'دریغ',
        'دریغا',
        'درین',
        'دسته دسته',
        'دشمنیم',
        'دقیقا',
        'دم',
        'دنبال',
        'ده',
        'دهد',
        'دهم',
        'دهند',
        'دهی',
        'دهید',
        'دهیم',
        'دو',
        'دو روزه',
        'دوباره',
        'دوم',
        'دیده',
        'دیر',
        'دیرت',
        'دیرم',
        'دیروز',
        'دیشب',
        'دیوانه‌ای',
        'دیوی',
        'دیگر',
        'دیگران',
        'دیگری',
        'دیگه',
        'ذ',
        'ذاتاً',
        'ر',
        'را',
        'راجع به',
        'راحت',
        'راسا',
        'راست',
        'راستی',
        'راه',
        'رسما',
        'رسید',
        'رسیده',
        'رشته',
        'رفت',
        'رفتارهاست',
        'رفته',
        'رنجند',
        'رهگشاست',
        'رو',
        'رواست',
        'روب',
        'روبروست',
        'روز',
        'روز به روز',
        'روزانه',
        'روزه ایم',
        'روزه ست',
        'روزه م',
        'روزهای',
        'روزه‌ای',
        'روش',
        'روی',
        'رویش',
        'روی',
        'ریزی',
        'ز',
        'زشتکارانند',
        'زمان',
        'زمانی',
        'زمینه',
        'زنند',
        'زهی',
        'زود',
        'زودتر',
        'زیاد',
        'زیاده',
        'زیر',
        'زیرا',
        'زیر',
        'زیرچشمی',
        'س',
        'سابق',
        'ساخته',
        'ساده اند',
        'سازی',
        'سالانه',
        'سالته',
        'سالم‌تر',
        'سالهاست',
        'سالیانه',
        'ساکنند',
        'سایر',
        'سخت',
        'سخته',
        'سر',
        'سراسر',
        'سرانجام',
        'سراپا',
        'سری',
        'سریع',
        'سریعا',
        'سریعاً',
        'سری',
        'سعی',
        'سمت',
        'سه باره',
        'سهواً',
        'سوم',
        'سوی',
        'سوی',
        'سپس',
        'سیاه چاله هاست',
        'سیخ',
        'ش',
        'شان',
        'شاهدند',
        'شاهدیم',
        'شاید',
        'شبهاست',
        'شخصا',
        'شخصاً',
        'شد',
        'شدم',
        'شدن',
        'شدند',
        'شده',
        'شدی',
        'شدید',
        'شدیدا',
        'شدیداً',
        'شدیم',
        'شش',
        'شش نداشته',
        'شما',
        'شماری',
        'شماست',
        'شمایند',
        'شناسی',
        'شو',
        'شود',
        'شوراست',
        'شوقم',
        'شوم',
        'شوند',
        'شونده',
        'شوی',
        'شوید',
        'شویم',
        'شیرین',
        'شیرینه',
        'شیک',
        'ص',
        'صد',
        'صددرصد',
        'صرفا',
        'صرفاً',
        'صریحاً',
        'صندوق هاست',
        'صورت',
        'ض',
        'ضدّ',
        'ضدّ',
        'ضمن',
        'ضمناً',
        'ط',
        'طبعا',
        'طبعاً',
        'طبق',
        'طبیعتا',
        'طرف',
        'طریق',
        'طلبکارانه',
        'طور',
        'طی',
        'ظ',
        'ظاهرا',
        'ظاهراً',
        'ع',
        'عاجزانه',
        'عاقبت',
        'عبارتند',
        'عجب',
        'عجولانه',
        'عدم',
        'عرفانی',
        'عقب',
        'عقب',
        'علاوه بر',
        'علاوه بر آن',
        'علاوه برآن',
        'علناً',
        'علّت',
        'علی الظاهر',
        'علی رغم',
        'علیرغم',
        'علیه',
        'عمدا',
        'عمداً',
        'عمدتا',
        'عمدتاً',
        'عمده',
        'عمل',
        'عملا',
        'عملاً',
        'عملی اند',
        'عموم',
        'عموما',
        'عموماً',
        'عنقریب',
        'عنوان',
        'عنوان',
        'عیناً',
        'غ',
        'غالبا',
        'غزالان',
        'غیر',
        'غیرقانونی',
        'ف',
        'فاقد',
        'فبها',
        'فر',
        'فردا',
        'فعلا',
        'فعلاً',
        'فقط',
        'فلان',
        'فلذا',
        'فوق',
        'فکر',
        'ق',
        'قاالند',
        'قابل',
        'قاطبه',
        'قاطعانه',
        'قاعدتاً',
        'قانوناً',
        'قبل',
        'قبلا',
        'قبلاً',
        'قبلند',
        'قدر',
        'قدری',
        'قصد',
        'قضایاست',
        'قطعا',
        'قطعاً',
        'ل',
        'لااقل',
        'لاجرم',
        'لب',
        'لذا',
        'لزوماً',
        'لطفا',
        'لطفاً',
        'لیکن',
        'م',
        'ما',
        'مادامی',
        'ماست',
        'مامان مامان گویان',
        'مان',
        'مانند',
        'مانند',
        'مبادا',
        'متؤسفانه',
        'متاسفانه',
        'متعاقبا',
        'متفاوتند',
        'مثل',
        'مثلا',
        'مثل',
        'مجانی',
        'مجبورند',
        'مجددا',
        'مجدداً',
        'مجموعا',
        'مجموعاً',
        'محتاجند',
        'محکم',
        'محکم‌تر',
        'مخالفند',
        'مختلف',
        'مخصوصاً',
        'مدام',
        'مدت',
        'مدتهاست',
        'مدّتی',
        'مذهبی اند',
        'مرا',
        'مرتب',
        'مردانه',
        'مردم',
        'مردم اند',
        'مرسی',
        'مستحضرید',
        'مستقیما',
        'مستند',
        'مسلما',
        'مشت',
        'مشترکاً',
        'مشغولند',
        'مطمانا',
        'مطمانم',
        'مطمینا',
        'مع الاسف',
        'مع ذلک',
        'معتقدم',
        'معتقدند',
        'معتقدیم',
        'معدود',
        'معذوریم',
        'معلومه',
        'معمولا',
        'معمولاً',
        'معمولی',
        'مغرضانه',
        'مفیدند',
        'مقابل',
        'مقدار',
        'مقصرند',
        'مقصری',
        'ملیارد',
        'ملیون',
        'ممکن',
        'ممیزیهاست',
        'من',
        'منتهی',
        'منطقی',
        'منی',
        'مواجهند',
        'موارد',
        'موجودند',
        'مورد',
        'موقتا',
        'مکرر',
        'مکرراً',
        'مگر',
        'مگر آن که',
        'مگر این که',
        'مگو',
        'می',
        'میان',
        'میزان',
        'میلیارد',
        'میلیون',
        'میکند',
        'میکنم',
        'میکنند',
        'میکنی',
        'میکنید',
        'میکنیم',
        'می‌تواند',
        'می‌خواهیم',
        'می‌داند',
        'می‌رسد',
        'می‌رود',
        'می‌شود',
        'می‌شوند',
        'می‌کنم',
        'می‌کنند',
        'می‌کنیم',
        'ن',
        'ناامید',
        'ناخواسته',
        'ناراضی اند',
        'ناشی',
        'نام',
        'ناگاه',
        'ناگزیر',
        'ناگهان',
        'ناگهانی',
        'نباید',
        'نبش',
        'نبود',
        'نخست',
        'نخستین',
        'نخواهد',
        'نخواهم',
        'نخواهند',
        'نخواهی',
        'نخواهید',
        'نخواهیم',
        'نخودی',
        'ندارد',
        'ندارم',
        'ندارند',
        'نداری',
        'ندارید',
        'نداریم',
        'نداشت',
        'نداشتم',
        'نداشتند',
        'نداشته',
        'نداشتی',
        'نداشتید',
        'نداشتیم',
        'نزد',
        'نزد',
        'نزدیک',
        'نزدیک',
        'نسبتا',
        'نشان',
        'نشده',
        'نظیر',
        'نفرند',
        'نماید',
        'نموده',
        'نمی',
        'نمی‌شود',
        'نمی‌کند',
        'نه',
        'نه تنها',
        'نهایتا',
        'نهایتاً',
        'نوع',
        'نوعاً',
        'نوعی',
        'نکرده',
        'نکن',
        'نکند',
        'نکنم',
        'نکنند',
        'نکنی',
        'نکنید',
        'نکنیم',
        'نگاه',
        'نگو',
        'نیازمندند',
        'نیز',
        'نیست',
        'نیستم',
        'نیستند',
        'نیستیم',
        'نیمی',
        'ه',
        'ها',
        'های',
        'هایی',
        'هبچ',
        'هر',
        'هر از گاهی',
        'هر چند',
        'هر چند که',
        'هر چه',
        'هرچند',
        'هرچه',
        'هرکس',
        'هرگاه',
        'هرگز',
        'هزار',
        'هست',
        'هستم',
        'هستند',
        'هستی',
        'هستید',
        'هستیم',
        'هفت',
        'هق هق کنان',
        'هم',
        'هم اکنون',
        'هم اینک',
        'همان',
        'همان طور که',
        'همان گونه که',
        'همانا',
        'همانند',
        'همانها',
        'همدیگر',
        'همزمان',
        'همه',
        'همه روزه',
        'همه ساله',
        'همه شان',
        'همهٌ',
        'همه‌اش',
        'همواره',
        'همچنان',
        'همچنان که',
        'همچنین',
        'همچون',
        'همچین',
        'همگان',
        'همگی',
        'همیشه',
        'همین',
        'همین که',
        'هنوز',
        'هنگام',
        'هنگام',
        'هنگامی',
        'هنگامی که',
        'هوی',
        'هی',
        'هیچ',
        'هیچ گاه',
        'هیچکدام',
        'هیچکس',
        'هیچگاه',
        'هیچگونه',
        'هیچی',
        'و',
        'و لا غیر',
        'وابسته اند',
        'واقعا',
        'واقعاً',
        'واقعی',
        'واقفند',
        'واما',
        'وای',
        'وجود',
        'وحشت زده',
        'وسط',
        'وضع',
        'وقتی',
        'وقتی که',
        'وقتیکه',
        'ولی',
        'وگرنه',
        'وگو',
        'وی',
        'ویا',
        'ویژه',
        'ّه',
        '٪',
        'پ',
        'پارسال',
        'پارسایانه',
        'پاره‌ای',
        'پاعین',
        'پایین ترند',
        'پدرانه',
        'پرسان',
        'پروردگارا',
        'پریروز',
        'پس',
        'پس از',
        'پس فردا',
        'پشت',
        'پشتوانه اند',
        'پشیمونی',
        'پنج',
        'پهن شده',
        'پی',
        'پی درپی',
        'پیدا',
        'پیداست',
        'پیرامون',
        'پیش',
        'پیشاپیش',
        'پیشتر',
        'پیش',
        'پیوسته',
        'چ',
        'چاپلوسانه',
        'چت',
        'چته',
        'چرا',
        'چرا که',
        'چشم بسته',
        'چطور',
        'چقدر',
        'چنان',
        'چنانچه',
        'چنانکه',
        'چند',
        'چند روزه',
        'چندان',
        'چنده',
        'چندین',
        'چنین',
        'چه',
        'چه بسا',
        'چه طور',
        'چهار',
        'چو',
        'چون',
        'چکار',
        'چگونه',
        'چی',
        'چیز',
        'چیزی',
        'چیزیست',
        'چیست',
        'چیه',
        'ژ',
        'ک',
        'کارند',
        'کاش',
        'کاشکی',
        'کامل',
        'کاملا',
        'کاملاً',
        'کتبا',
        'کجا',
        'کجاست',
        'کدام',
        'کرد',
        'کردم',
        'کردن',
        'کردند',
        'کرده',
        'کردی',
        'کردید',
        'کردیم',
        'کس',
        'کسانی',
        'کسی',
        'کل',
        'کلا',
        'کلی',
        'کلیه',
        'کم',
        'کم کم',
        'کمااینکه',
        'کماکان',
        'کمتر',
        'کمتره',
        'کمتری',
        'کمی',
        'کن',
        'کنار',
        'کنارش',
        'کنار',
        'کنایه‌ای',
        'کند',
        'کنم',
        'کنند',
        'کننده',
        'کنون',
        'کنونی',
        'کنی',
        'کنید',
        'کنیم',
        'که',
        'کو',
        'کَی',
        'کی',
        'گ',
        'گاه',
        'گاهی',
        'گذاری',
        'گذاشته',
        'گذشته',
        'گردد',
        'گردند',
        'گرفت',
        'گرفتارند',
        'گرفتم',
        'گرفتن',
        'گرفتند',
        'گرفته',
        'گرفتی',
        'گرفتید',
        'گرفتیم',
        'گروهی',
        'گرچه',
        'گفت',
        'گفتم',
        'گفتن',
        'گفتند',
        'گفته',
        'گفتی',
        'گفتید',
        'گفتیم',
        'گه',
        'گهگاه',
        'گو',
        'گونه',
        'گوی',
        'گویا',
        'گوید',
        'گویم',
        'گویند',
        'گویی',
        'گویید',
        'گوییم',
        'گیر',
        'گیرد',
        'گیرم',
        'گیرند',
        'گیری',
        'گیرید',
        'گیریم',
        'ی',
        'یا',
        'یاب',
        'یابد',
        'یابم',
        'یابند',
        'یابی',
        'یابید',
        'یابیم',
        'یارب',
        'یافت',
        'یافتم',
        'یافتن',
        'یافته',
        'یافتی',
        'یافتید',
        'یافتیم',
        'یعنی',
        'یقینا',
        'یقیناً',
        'یه',
        'یواش یواش',
        'یک',
        'یک جوری',
        'یک کم',
        'یک کمی',
        'یکدیگر',
        'یکریز',
        'یکسال',
        'یکهزار',
        'یکی',
        '۰',
        '۱',
        '۲',
        '۳',
        '۴',
        '۵',
        '۶',
        '۷',
        '۸',
        '۹',
        '…',
        '﻿و',
        'کن',
        'کرد',
        'کردن',
        'باش',
        'بود',
        'بودن',
        'شو',
        'شد',
        'شدن',
        'دار',
        'داشت',
        'داشتن',
        'خواه',
        'خواست',
        'خواستن',
        'گوی',
        'گفت',
        'گفتن',
        'گیر',
        'گرفت',
        'گرفتن',
        'آی',
        'آمد',
        'آمدن',
        'توان',
        'توانست',
        'توانستن',
        'یاب',
        'یافت',
        'یافتن',
        'آور',
        'آورد',
        'آوردن',
    ]
